#
# spec file
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname typing_extensions
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-typing_extensions%{psuffix}
Version:        3.10.0.0
Release:        150400.3.2.1
Summary:        Backported and Experimental Type Hints for Python 35+
License:        Python-2.0
URL:            https://github.com/python/typing/
Source0:        https://files.pythonhosted.org/packages/source/t/typing_extensions/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Provides:       python-typing-extensions = %{version}
%if 0%{?suse_version} > 1320 && %{with test}
BuildRequires:  %{python_module testsuite}
%endif
%if %{with python2}
BuildRequires:  python-typing >= 3.7.4
%endif
BuildRequires:  (python3-typing >= 3.7.4 if python3-base < 3.5)
%if %{python_version_nodots} < 35
Requires:       python-typing >= 3.7.4
%endif
%python_subpackages

%description
The ``typing`` module was added to the standard library in Python
3.5 on a provisional basis and will no longer be provisional in
Python 3.7. However, this means users of Python 3.5 - 3.6 who are
unable to upgrade will not be able to take advantage of new types
added to the ``typing`` module, such as ``typing.Text`` or
``typing.Coroutine``.

The ``typing_extensions`` module contains both backports of these
changes as well as experimental types that will eventually be
added to the ``typing`` module, such as ``Protocol``.

Users of other Python versions should continue to install and use
the ``typing`` module from PyPi instead of using this one unless
specifically writing code that must be compatible with multiple
Python versions or requires experimental types.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%if ! %{with test}
%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# X.Y -> X
%{python_expand current_bin_suffix=%{$python_bin_suffix}
$python src_py${current_bin_suffix:0:1}/test_typing_extensions.py
}
%endif

%if ! %{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/typing_extensions.py*
%pycache_only %{python_sitelib}/__pycache__/typing_extensions*
%{python_sitelib}/typing_extensions-%{version}*-info
%endif

%changelog
* Mon Jul 12 2021 mmachova@suse.com
- Update to 3.10.0.0
  * Implement TypeGuard (PEP 649)
  * backport ParamSpecArgs/Kwargs
  * Fixed required/optional keys with old-style TypedDict
  * Bring in protocol’s __init__ behaviour same like in python > 3.8
  * Support PEP 612 in typing_extensions (Python 3)
  * Add OrderedDict to typing_extensions
* Tue Jan 12 2021 code@bnavigator.de
- Test in separate multibuild flavor to break depcycles with full
  python stdlib
* Tue Jan 12 2021 code@bnavigator.de
- clean requirements specifications for python flavors
* Sun Dec 20 2020 dmueller@suse.com
- add transitional typing-extensions provides
* Wed Nov  4 2020 mcepl@suse.com
- Use python_module macro for BuildRequires when available.
* Thu Oct 15 2020 dmueller@suse.com
- update to version 3.7.4.3:
  * enables PEP 613 Typealias to typing_extensions
  * Fix tests for Python 3.9
* Mon Apr  6 2020 mcalabkova@suse.com
- update to version 3.7.4.2
  * official support for Python 3.8 and 3.9
* Thu Mar 12 2020 tchvatal@suse.com
- Fix build without python2 available
* Wed Nov  6 2019 lars@linux-schulserver.de
- Update to version 3.7.4.1:
  + Fix isinstance() with generic protocol subclasses after subscripting
  + Fix tests for non-default interpreters
  + Use environment marker to specify typing dependency
  + Fix unions of protocols on Python 2
* Sun Jul 21 2019 sebix+novell.com@sebix.at
- Update to version 3.7.4:
  - No changelog available.
- Drop test-sys-executable.patch, merged upstream.
* Sat Mar  2 2019 tchvatal@suse.com
- Rebase the patch to the current git state
* Sat Mar  2 2019 jayvdb@gmail.com
- Add support for Python <3.5, using upstream commit as
  test-sys-executable.patch to fix the tests, replacing custom sed.
- Remove unnecessary buid dependency on pytest and pytest-xdist
* Thu Feb 28 2019 tchvatal@suse.com
- Drop the old tarball
* Thu Feb 28 2019 jayvdb@gmail.com
- Replace test_modules.tar.gz with python-testsuite
- Remove fix_tests.patch which is half fixing test_modules.tar.gz,
  and the other half is replaced with a less brittle sed.
- Remove unnecessary build dependencies
- Update to 3.7.2
  * Pass *args and **kwargs to superclass in Generic.__new__
  * Fix for issue #524
  * Fix typing_extensions to support PEP 560
  * Add annotations to NamedTuple children __new__ constructors
  * Add missing 'NoReturn' to __all__ in typing.py
  * Backport Generic.__new__ fix
  * Fix IO.closed to be property
  * Add Final to typing_extensions
  * Fix instance/subclass checks of functions against runtime protocols
  * Add Literal[...] types to typing_extensions
* Tue Oct 23 2018 mcepl@suse.com
- Initial effort to package typing_extensions-3.6.6
